@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2000-2002 ASANO Masahiro
+ * Copyright (C) 2000-2003 ASANO Masahiro
  */
 
 #include <unistd.h>
@@ -61,7 +61,7 @@ tq_struct()
 	} else {
 		prhead_tq_struct();
 		while (args[optind]) {
-			addr = getaddr(args[optind]);
+			addr = getvalue(args[optind]);
 			while (addr && addr != tqlist[i].addr) {
 				addr_t next = print_tq_struct(addr);
 				if (addr == next)
