@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2000-2003 ASANO Masahiro
+ * Copyright (C) 2000-2005 ASANO Masahiro
  */
 
 #include "def.h"
@@ -68,8 +68,12 @@ print_zone(addr, full)
 			mprintf(FPTR " ", fp->free_list.prev);
 		}
 #ifdef _free_area_has_map
-		mprintf(" " FPTR "\n", fp->map);
+		mprintf(" " FPTR, fp->map);
 #endif
+#ifdef _free_area_has_nr_free
+		mprintf("  %lx", fp->nr_free);
+#endif
+		mprintf("\n");
 	}
 	mprintf("wait_table         " FPTR "\n", zone.wait_table);
 	mprintf("wait_table_size    %lx  (2^%lx)\n",
@@ -145,6 +149,12 @@ print_pglist_data(addr)
 		pg.node_present_pages, pg.node_spanned_pages);
 	mprintf("node_id            %x\n", pg.node_id);
 	mprintf("pgdat_next         " FPTR "\n", pg.pgdat_next);
+#ifdef _pglist_data_has_kswapd
+	mprintf("kswapd             " FPTR "\n", pg.kswapd);
+#endif
+#ifdef _pglist_data_has_kswapd_max_order
+	mprintf("kswapd_max_order   %x\n", pg.kswapd_max_order);
+#endif
 	return (addr_t)pg.pgdat_next;
 }
 
