@@ -300,9 +300,13 @@ print_mm_struct(addr, vflag)
 			mm.arg_start, mm.arg_end);
 		mprintf("env:        " FPTR " " FPTR "\n",
 			mm.env_start, mm.env_end);
-		mprintf("rss:        %lx\n", mm.rss);
 		mprintf("total_vm    %lx\n", mm.total_vm);
 		mprintf("locked_vm:  %lx\n", mm.locked_vm);
+#ifdef _mm_struct_has__rss
+		mprintf("_rss:       %lx\n", mm._rss);
+#else
+		mprintf("rss:        %lx\n", mm.rss);
+#endif
 		mprintf("def_flags:  %lx\n", mm.def_flags);
 		mprintf("cpu_vm_mask:%lx\n", mm.cpu_vm_mask);
 	}
