@@ -197,6 +197,7 @@ trace()
 		}
 		retad = *(unsigned int *)&stack[esp - stacktop];
 		if ((sym = searchsym_byaddr(retad)) == NULL ||
+		    retad - sym->addr > 0x10000 ||
 		    (sym->addr <= retad && sym->addr + 1 >= retad)) {
 			/* maybe stack analyze fail, do RECOVERY code */
 			/* save the pointers */
@@ -220,7 +221,7 @@ trace()
 			mprintf("?");
 		}
 
-		memread(retad, sizeof(funchead), funchead, sym->name);
+		memread(retad, sizeof(funchead), funchead, "return-address");
 		if ((funchead[0] == 0xe9 || (ISPOP(funchead[0]) && (funchead[1] == 0xe9 || ISPOP(funchead[1]) && funchead[2] == 0xe9))) &&
 		    (strcmp(sym->name, "stext_lock") == 0 || strncmp(sym->name, "_text_lock_", 11) == 0 || strncmp(sym->name, ".text.lock.", 11) == 0)) {
 			mprintf(")\n[%8lx] %8lx  [%s]\n", esp, retad, getsymstr(retad));
@@ -252,7 +253,7 @@ trace()
 			} else if (c == 0xe9) {
 				if (i > 0)
 					break;
-				memread(retad + i + 5 + funchead[1] + funchead[2] * 256, sizeof(funchead), funchead, sym->name);
+				memread(retad + i + 5 + funchead[1] + funchead[2] * 256, sizeof(funchead), funchead, "jmp(e9)");
 				/* add esp,xx */
 				if (funchead[0] == 0x83 && funchead[1] == 0xc4)
 					argsize = (signed char)funchead[2];
@@ -261,7 +262,7 @@ trace()
 			} else if (c == 0xeb) {
 				if (i > 0)
 					break;
-				memread(retad + i + 2 + (signed char)funchead[1], sizeof(funchead), funchead, sym->name);
+				memread(retad + i + 2 + (signed char)funchead[1], sizeof(funchead), funchead, "jmp(eb)");
 				/* add esp,xx */
 				if (funchead[0] == 0x83 && funchead[1] == 0xc4)
 					argsize = (signed char)funchead[2];
