@@ -38,7 +38,7 @@ PRIVATE char token_sym[128];
 
 PRIVATE addr_t
 gethex(statep)
-const char **statep;
+	const char **statep;
 {
 	const char *curp = *statep;
 	addr_t v, n;
@@ -66,8 +66,8 @@ const char **statep;
 
 PRIVATE int
 gettoken(statep, valuep)
-const char **statep;
-addr_t *valuep;
+	const char **statep;
+	addr_t *valuep;
 {
 	const char *curp = *statep;
 	const char *save;
@@ -162,7 +162,7 @@ enum oppri {
 
 PRIVATE enum oppri
 getoppri(c)
-	int	c;
+	int c;
 {
 	switch (c) {
 	case '*':
@@ -208,7 +208,7 @@ getoppri(c)
 
 PRIVATE addr_t
 term(statep)
-const char **statep;
+	const char **statep;
 {
 	int c;
 	addr_t value;
@@ -283,9 +283,9 @@ const char **statep;
 
 PRIVATE addr_t
 expr2(statep, value, pri0)
-const char **statep;
-addr_t value;
-enum oppri pri0;
+	const char **statep;
+	addr_t value;
+	enum oppri pri0;
 {
 	const char *save;
 	addr_t nextvalue;
@@ -303,7 +303,7 @@ enum oppri pri0;
 		save = *statep;
 		pri2 = getoppri(gettoken(statep, (addr_t *)NULL));
 		*statep = save;
-		if ((int)pri1 <= (int)pri2) {
+		if ((int)pri1 < (int)pri2) {
 			nextvalue = expr2(statep, nextvalue, pri1);
 		}
 
@@ -336,14 +336,14 @@ enum oppri pri0;
 
 PRIVATE addr_t
 expr(statep)
-const char **statep;
+	const char **statep;
 {
 	return expr2(statep, term(statep), OPPRIERR);
 }
 
 addr_t
 getvalue(str)
-const char *str;
+	const char *str;
 {
 	addr_t n;
 	const char **statep = &str;
