@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2000-2002 ASANO Masahiro
+ * Copyright (C) 2000-2003 ASANO Masahiro
  */
 
 #include <unistd.h>
@@ -34,7 +34,7 @@ filesystem()
 		}
 	} else {
 		for (i = optind; i < argcnt; i++) {
-			addr = print_file_system_type(getaddr(args[i]));
+			addr = print_file_system_type(getvalue(args[i]));
 		}
 	}
 	return addr;
