@@ -11,6 +11,8 @@
 #include <xfs_buf_item.h>
 #include <xfs_inode_item.h>
 #include <xfs_extfree_item.h>
+#include <xfs_quota.h>
+#include <xfs_dquot_item.h>
 
 #include "flags_trans.h"
 
@@ -21,6 +23,29 @@ prhead_xfs_log_item()
 		"ADDR", "DESC", "MOUNTP", "BIO_LIST", "CB", "OPS");
 }
 
+PRIVATE void
+prlogitem_type(type)
+	int type;
+{
+	switch (type) {
+	case XFS_LI_5_3_BUF:	mprintf("5.3BUF  ");	break;
+	case XFS_LI_5_3_INODE:	mprintf("5.3INODE");	break;
+	case XFS_LI_EFI:	mprintf("EFI     ");	break;
+	case XFS_LI_EFD:	mprintf("EFD     ");	break;
+	case XFS_LI_IUNLINK:	mprintf("IUNLINK ");	break;
+	case XFS_LI_6_1_INODE:	mprintf("6.1INODE");	break;
+	case XFS_LI_6_1_BUF:	mprintf("6.1BUF  ");	break;
+	case XFS_LI_INODE:	mprintf("INODE   ");	break;
+	case XFS_LI_BUF:	mprintf("BUF     ");	break;
+	case XFS_LI_DQUOT:	mprintf("DQUOT   ");	break;
+	case XFS_LI_QUOTAOFF:	mprintf("QUOTAOFF");	break;
+#ifdef XFS_LI_RPC
+	case XFS_LI_RPC:	mprintf("RPC     ");	break;
+#endif
+	default:		mprintf("UNKNOWN ");	break;
+	}
+}
+
 addr_t
 print_xfs_log_item(addr, full)
 	addr_t addr;
@@ -41,22 +66,7 @@ print_xfs_log_item(addr, full)
 	mprintf(" " FPTR " " FPTR " " FPTR " ",
 		li.li_bio_list, li.li_cb, li.li_ops);
 
-	switch (li.li_type) {
-	case XFS_LI_5_3_BUF:	mprintf("5.3BUF  ");	break;
-	case XFS_LI_5_3_INODE:	mprintf("5.3INODE");	break;
-	case XFS_LI_EFI:	mprintf("EFI     ");	break;
-	case XFS_LI_EFD:	mprintf("EFD     ");	break;
-	case XFS_LI_IUNLINK:	mprintf("IUNLINK ");	break;
-	case XFS_LI_6_1_INODE:	mprintf("6.1INODE");	break;
-	case XFS_LI_6_1_BUF:	mprintf("6.1BUF  ");	break;
-	case XFS_LI_INODE:	mprintf("INODE   ");	break;
-	case XFS_LI_BUF:	mprintf("BUF     ");	break;
-	case XFS_LI_DQUOT:	mprintf("DQUOT   ");	break;
-	case XFS_LI_QUOTAOFF:	mprintf("QUOTAOFF");	break;
-#ifdef XFS_LI_RPC
-	case XFS_LI_RPC:	mprintf("RPC     ");	break;
-#endif
-	}
+	prlogitem_type(li.li_type);
 	mprintbit(liflags, li.li_flags);
 	mprintf("\n");
 
@@ -79,7 +89,7 @@ print_xfs_log_item(addr, full)
 			mprintf("\n");
 			mprintf("  recur:    %x\n", bli.bli_recur);
 			mprintf("  refcount: %x\n", ATOMIC_READ(bli.bli_refcount));
-#if 0
+#if 1
 			mprintf("  format.size:     %x\n", bli.bli_format.blf_size);
 			mprintf("  format.flags:    %x\n", bli.bli_format.blf_flags);
 			mprintf("  format.len:      %x\n", bli.bli_format.blf_len);
@@ -117,8 +127,12 @@ print_xfs_log_item(addr, full)
 			mprintbit(efiflags, efi.efi_flags);
 			mprintf("\n");
 			mprintf("  next_extent: %x\n", efi.efi_next_extent);
-#if 0
-			mprintf("  format.size: %x\n", efi.efi_format.efi_size);
+#if 1
+			mprintf("  format.type:     %x\n", efi.efi_format.efi_type);
+			mprintf("  format.size:     %x\n", efi.efi_format.efi_size);
+			mprintf("  format.nextents: %x\n", efi.efi_format.efi_nextents);
+			mprintf("  format.id:       %x\n",efi.efi_format.efi_id);
+			mprintf("  format.extents0: %lx\n", efi.efi_format.efi_extents[0]);
 #endif
 			break;
 		}
@@ -129,6 +143,13 @@ print_xfs_log_item(addr, full)
 			mprintf("  next_extent: %x\n", efd.efd_next_extent);
 			break;
 		}
+		case XFS_LI_DQUOT: {
+			xfs_dq_logitem_t logitem;
+			memread(addr, sizeof(logitem), &logitem, "xfs_dq_logitem");
+			mprintf("  dquot: " FPTR "\n", logitem.qli_dquot);
+			mprintf("  pushbuf_flag: %x\n", logitem.qli_pushbuf_flag);
+			break;
+		}
 		}
 	}
 
@@ -276,6 +297,7 @@ print_xfs_trans(addr, aflag)
 	mprintf("items.next:   " FPTR "\n",   trans.t_items.lic_next);
 	mprintf("items.free/unused:   %x %x\n",trans.t_items.lic_free,
 					      trans.t_items.lic_unused);
+	mprintf("               " SPTR "  TYPE      SIZ IDX  FLAGS\n", "ITEM");
 	for (i = 0; i < XFS_LIC_NUM_SLOTS; i++) {
 		static const struct bitname lidflags[] = {
 			{ XFS_LID_DIRTY,	"dirty" },
@@ -290,8 +312,19 @@ print_xfs_trans(addr, aflag)
 		};
 		if (XFS_LIC_ISFREE(&trans.t_items, i))
 			continue;
-		mprintf("items.descs%2x: " FPTR "%4x %3x ", i,
-			trans.t_items.lic_descs[i].lid_item,
+		mprintf("items.descs%2x: " FPTR " ", i,
+			trans.t_items.lic_descs[i].lid_item);
+		if (trans.t_items.lic_descs[i].lid_item) {
+			xfs_log_item_t li;
+			memread((addr_t)trans.t_items.lic_descs[i].lid_item,
+				sizeof(li), &li, "xfs_log_item_t");
+			mprintf("(");
+			prlogitem_type(li.li_type);
+			mprintf(")");
+		} else {
+			mprintf(" -        ");
+		}
+		mprintf("%4x %3x ",
 			trans.t_items.lic_descs[i].lid_size,
 			trans.t_items.lic_descs[i].lid_index);
 		mprintbit(lidflags, trans.t_items.lic_descs[i].lid_flags);
